@@ -35,12 +35,23 @@ using namespace gdcm;
 
 DEFUN_DLD (dicomuid, args, nargout,
     "-*- texinfo -*- \n\
-@deftypefn {Loadable Function} @var{uuid} = dicomuuid () \n\
+@deftypefn {Loadable Function} @var{uuid} = dicomuid () \n\
 \n\
 Generate a DICOM unique id . \n\
 \n \
+@subsubheading Inputs\n\
+None\n\
+@subsubheading Outputs\n\
 @var{uuid} is a unique id string.\n\
 \n\
+@subsubheading Examples\n\
+Get a new uid:\n\
+\n\
+@example\n\
+> uid = dicomuid ()\n\
+uid = 1.2.826.0.1.3680043.2.1143.3114589836670200378351641061429967573\n\
+@end example\n\
+\n\
 @end deftypefn \n\
 ")
 {
